# active-win-url [![Build Status](https://travis-ci.org/robertjkeck2/active-win.svg?branch=master)](https://travis-ci.org/robertjkeck2/active-win)

Get metadata about the [active window](https://en.wikipedia.org/wiki/Active_window) (URL, title, id, bounds, owner, etc)

Works on macOS.

Users on macOS 10.13 or earlier needs to download the [Swift runtime support libraries](https://support.apple.com/kb/DL1998).


## Install

```
$ npm install active-win-url
```


## Usage

```js
const activeWin = require('active-win-url');

(async () => {
	console.log(await activeWin());
	/*
	{
		title: 'Unicorns - Google Search',
		id: 5762,
		bounds: {
			x: 0,
			y: 0,
			height: 900,
			width: 1440
		},
		owner: {
			name: 'Google Chrome',
			processId: 310,
			bundleId: 'com.google.Chrome',
			path: '/Applications/Google Chrome.app'
		},
		url: 'https://google.com/unicorns',
		memoryUsage: 11015432
	}
	*/
})();
```


## API

### activeWin()

Returns a `Promise<Object>` with the result, or `Promise<undefined>` if there is no active window or if the information is not available.

### activeWin.sync()

Returns an `Object` with the result, or `undefined` if there is no active window.


## Result

- `platform` *(string)* - `'macos'` | `'linux'` | `'windows'`
- `title` *(string)* - Window title
- `id` *(number)* - Window identifier
- `bounds` *(Object)* - Window position and size
	- `x` *(number)*
	- `y` *(number)*
	- `width` *(number)*
	- `height` *(number)*
- `owner` *(Object)* - App that owns the window
	- `name` *(string)* - Name of the app
	- `processId` *(number)* - Process identifier
	- `bundleId` *(string)* - Bundle identifier *(macOS only)*
	- `path` *(string)* - Path to the app
- `url` *(string)* - URL of active window if browser
- `memoryUsage` *(number)* - Memory usage by the window owner process


## OS support

It works on macOS.

## Related

- [active-win](https://github.com/sindresorhus/active-win) - Original active-win module
- [active-win-cli](https://github.com/sindresorhus/active-win-cli) - CLI for this module
- [active-win-log](https://github.com/uglow/active-win-log) - Window-usage logging CLI using this module

## Maintainers

- [Sindre Sorhus](https://github.com/sindresorhus)
- [Sebastián Ramírez](https://github.com/tiangolo)
- [John Keck](https://github.com/robertjkeck2)
